@@ -152,13 +152,14 @@ module Octokit
       # @return [Sawyer::Resource] Repository info for the new repository
       # @see https://developer.github.com/v3/repos/#create
       def create_repository(name, options = {})
-        organization = options.delete :organization
-        options.merge! :name => name
+        opts = options.dup
+        organization = opts.delete :organization
+        opts.merge! :name => name
 
         if organization.nil?
-          post 'user/repos', options
+          post 'user/repos', opts
         else
-          post "#{Organization.path organization}/repos", options
+          post "#{Organization.path organization}/repos", opts
         end
       end
       alias :create_repo :create_repository
@@ -276,6 +277,9 @@ module Octokit
       # Requires authenticated client for private repos.
       #
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
+      # @option options [String] :affiliation Filters the return array by affiliation.
+      #   Can be one of: <tt>outside</tt> or <tt>all</tt>.
+      #   If not specified, defaults to <tt>all</tt>
       # @return [Array<Sawyer::Resource>] Array of hashes representing collaborating users.
       # @see https://developer.github.com/v3/repos/collaborators/#list-collaborators
       # @example
@@ -291,16 +295,24 @@ module Octokit
 
       # Add collaborator to repo
       #
+      # This can also be used to update the permission of an existing collaborator
+      #
       # Requires authenticated client.
       #
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
       # @param collaborator [String] Collaborator GitHub username to add.
+      # @option options [String] :permission The permission to grant the collaborator.
+      #   Only valid on organization-owned repositories.
+      #   Can be one of: <tt>pull</tt>, <tt>push</tt>, or <tt>admin</tt>.
+      #   If not specified, defaults to <tt>push</tt>
       # @return [Boolean] True if collaborator added, false otherwise.
       # @see https://developer.github.com/v3/repos/collaborators/#add-user-as-a-collaborator
       # @example
       #   @client.add_collaborator('octokit/octokit.rb', 'holman')
       # @example
       #   @client.add_collab('octokit/octokit.rb', 'holman')
+      # @example Add a collaborator with admin permissions
+      #   @client.add_collaborator('octokit/octokit.rb', 'holman', permission: 'admin')
       def add_collaborator(repo, collaborator, options = {})
         boolean_from_response :put, "#{Repository.path repo}/collaborators/#{collaborator}", options
       end
@@ -337,6 +349,19 @@ module Octokit
         boolean_from_response :get, "#{Repository.path repo}/collaborators/#{collaborator}", options
       end
 
+      # Get a user's permission level for a repo.
+      #
+      # Requires authenticated client
+      #
+      # @return [Sawyer::Resource] Hash representing the user's permission level for the given repository
+      # @see https://developer.github.com/v3/repos/collaborators/#review-a-users-permission-level
+      # @example
+      #   @client.permission_level('octokit/octokit.rb', 'lizzhale')
+      def permission_level(repo, collaborator, options={})
+        options = ensure_api_media_type(:org_memberships, options)
+        get "#{Repository.path repo}/collaborators/#{collaborator}/permission", options
+      end
+
       # List teams for a repo
       #
       # Requires authenticated client that is an owner or collaborator of the repo.
@@ -490,20 +515,43 @@ module Octokit
       #
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
       # @param branch [String] Branch name
-      # @param required_status_checks [Hash]
+      # @option options [Hash] :required_status_checks If not null, the following keys are required:  
+      #   <tt>:include_admins [boolean] Enforce required status checks for repository administrators.</tt>  
+      #   <tt>:strict [boolean] Require branches to be up to date before merging.</tt>  
+      #   <tt>:contexts [Array] The list of status checks to require in order to merge into this branch</tt>  
+      #
+      # @option options [Hash] :restrictions If not null, the following keys are required:
+      #   <tt>:users [Array] The list of user logins with push access</tt>  
+      #   <tt>:teams [Array] The list of team slugs with push access</tt>.  
+      #
+      #   Teams and users restrictions are only available for organization-owned repositories.
       # @return [Sawyer::Resource] The protected branch
       # @see https://developer.github.com/v3/repos/#enabling-and-disabling-branch-protection
       # @example
       #   @client.protect_branch('octokit/octokit.rb', 'master', foo)
-      def protect_branch(repo, branch, required_status_checks = {}, options = {})
-        if !required_status_checks.empty?
-          required_status_checks = { :required_status_checks => required_status_checks }
+      def protect_branch(repo, branch, options = {})
+        opts = ensure_api_media_type(:branch_protection, options)
+        opts[:restrictions] ||= nil
+        opts[:required_status_checks] ||= nil
+        put "#{Repository.path repo}/branches/#{branch}/protection", opts
+      end
+
+      # Get branch protection summary
+      #
+      # @param repo [Integer, String, Hash, Repository] A GitHub repository.
+      # @param branch [String] Branch name
+      # @return [Sawyer::Resource, nil] Branch protection summary or nil if the branch
+      #   is not protected
+      # @see https://developer.github.com/v3/repos/branches/#get-branch-protection
+      # @example
+      #   @client.branch_protection('octokit/octokit.rb', 'master')
+      def branch_protection(repo, branch, options = {})
+        opts = ensure_api_media_type(:branch_protection, options)
+        begin
+          get "#{Repository.path repo}/branches/#{branch}/protection", opts
+        rescue Octokit::BranchNotProtected
+          nil
         end
-
-        protection = { :protection => { :enabled => true }.merge(required_status_checks) }
-        options    = ensure_api_media_type(:branch_protection, options.merge(protection))
-
-        patch "#{Repository.path repo}/branches/#{branch}", options
       end
 
       # Unlock a single branch from a repository
@@ -517,9 +565,8 @@ module Octokit
       # @example
       #   @client.unprotect_branch('octokit/octokit.rb', 'master')
       def unprotect_branch(repo, branch, options = {})
-        protection = { :protection => { :enabled => false } }
-        options = ensure_api_media_type(:branch_protection, options.merge(protection))
-        patch "#{Repository.path repo}/branches/#{branch}", options
+        opts = ensure_api_media_type(:branch_protection, options)
+        boolean_from_response :delete, "#{Repository.path repo}/branches/#{branch}/protection", opts
       end
 
       # List users available for assigning to issues.
